sessionUpdate abstract method

Future<ForgeOutcome> sessionUpdate(
  1. Map<String, String> params,
  2. Map<String, double> metrics
)

Hot session update (session-update mode): flat stringified dimension params plus numeric session metrics staged by the kernel and carried on the next session event or an update beat.

Implementation

Future<ForgeOutcome> sessionUpdate(
  Map<String, String> params,
  Map<String, double> metrics,
);