capturePlan method
Pull accessor for the latest kernel-emitted capture plan, or null before the first plan emission (plans emit from the first session start onward).
Implementation
@override
Future<Map<String, Object?>?> capturePlan() async => null;
Pull accessor for the latest kernel-emitted capture plan, or null before the first plan emission (plans emit from the first session start onward).
@override
Future<Map<String, Object?>?> capturePlan() async => null;